@@ -50,7 +50,7 @@ class MTMLflowCallback(MLflowCallbackBase):
         )
 
     def register_model(self, trainer, pl_module):
-        mlflow.gluon.log_model(
+        mlflow.pytorch.log_model(
             pytorch_model=pl_module.multi_task,
             artifact_path="model",
             conda_env=None,
