@@ -1,13 +1,15 @@
-
+import copy
 import os
+import shutil
 import time
+import math
 import json
 import numpy as np
 import pandas as pd
 import boto3
 import torch
 import wandb
-from torch.utils.data import Dataset
+from torch.utils.data import Dataset, IterableDataset, DataLoader
 import mlflow
 import pytorch_lightning as pl
 from pytorch_lightning import LightningModule
@@ -141,6 +143,7 @@ class TxTOrderDataset(Dataset):
         for i, key in enumerate(keys):
             obj = s3_client.get_object(Bucket=self.s3_bucket, Key=key)
             df = self._read_df(obj['Body'], file_format=self.data_file_format)
+            # df = df[df["is_pos"] == True]
             self._append_np_from_df(df)
             if i > self.parts_num:
                 break
@@ -153,6 +156,7 @@ class TxTOrderDataset(Dataset):
         ]
         for i, f_path in enumerate(f_paths):
             df = self._read_df(f_path, self.data_file_format)
+            # df = df[df["is_pos"] == True]
             self._append_np_from_df(df)
             if i > self.parts_num:
                 break
